"use client";

import Image from "next/image";

import { useTranslations } from "next-intl";

import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useMemo } from "react";


export default function Statistics() {
	const t = useTranslations();
	const { texts } = useBasicInfo();


	const keys = useMemo(() => [
		{ label: "countries", value: texts?.number_of_countries },
		{ label: "experts", value: texts?.years_of_experience },
		{ label: "agents", value: texts?.number_of_clients },
		{ label: "projects", value: texts?.number_of_projects },

	], [texts]);

	const hasValues = texts?.number_of_countries || texts?.years_of_experience || texts?.number_of_clients || texts?.number_of_projects;

	return (
		hasValues && (
			<section className="relative overflow-hidden bg-[#2A99CB]">
				{/* Background Ornament */}
				<div className="pointer-events-none absolute inset-0">
					<Image
						src={"/ornament.png"}
						alt=""
						fill
						className="object-cover opacity-40"
					/>
				</div>

				<div className="container relative z-10 mx-auto px-4 py-8 lg:px-40">
					<div className="grid grid-cols-2 gap-8 text-center text-white md:grid-cols-4 md:gap-4">
						{keys?.map(({ label, value }, index) => {
							return (
								<div
									key={index}
									className="flex flex-col items-center justify-center"
								>
									<span className="mb-2 text-3xl font-bold md:text-4xl">
										{value}
									</span>
									<span className="text-lg md:text-xl">{t(label)}</span>
								</div>
							);
						})}
					</div>
				</div>

				{/* Divider Lines */}
				<div className="pointer-events-none absolute left-1/2 top-1/2 h-full w-full -translate-x-1/2 -translate-y-1/2">
					<div className="container mx-auto h-full px-4 lg:px-40">
						<div className="hidden h-full grid-cols-4 md:grid">
							<div className="border-r border-white/20" />
							<div className="border-r border-white/20" />
							<div className="border-r border-white/20" />
						</div>
					</div>
				</div>
			</section>
		)
	);
}
